@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """digitalocean API to manage droplets"""
 
-__version__ = "1.12"
+__version__ = "1.14.0"
 __author__ = "Lorenzo Setale ( http://who.is.lorenzo.setale.me/? )"
 __author_email__ = "lorenzo@setale.me"
 __license__ = "LGPL v3"
@@ -26,3 +26,4 @@ from .LoadBalancer import LoadBalancer
 from .LoadBalancer import StickySesions, ForwardingRule, HealthCheck
 from .Certificate import Certificate
 from .Snapshot import Snapshot
+from .Firewall import Firewall, InboundRule, OutboundRule, Destinations, Sources
